Stan Math Library: Namespace Members

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- Namespace List
- Namespace Members

- All
- Functions
- Variables
- Typedefs

- a
- b
- c
- d
- e
- f
- g
- h
- i
- j
- l
- m
- n
- o
- p
- q
- r
- s
- t
- u
- v
- w

### - m -

- machine_precision() : stan::math
- make_nu() : stan::math
- matrix_normal_prec_log() : stan::math
- max() : stan::math
- max_size() : stan
- max_size_mvt() : stan
- mdivide_left() : stan::math
- mdivide_left_ldlt() : stan::math
- mdivide_left_spd() : stan::math
- mdivide_left_tri() : stan::math
- mdivide_left_tri_low() : stan::math
- mdivide_right() : stan::math
- mdivide_right_ldlt() : stan::math
- mdivide_right_spd() : stan::math
- mdivide_right_tri() : stan::math
- mdivide_right_tri_low() : stan::math
- mean() : stan::math
- min() : stan::math
- minus() : stan::math
- modified_bessel_first_kind() : stan::math
- modified_bessel_second_kind() : stan::math
- modulus() : stan::math
- multi_gp_cholesky_log() : stan::math
- multi_gp_log() : stan::math
- multi_normal_cholesky_log() : stan::math
- multi_normal_cholesky_rng() : stan::math
- multi_normal_log() : stan::math
- multi_normal_prec_log() : stan::math
- multi_normal_rng() : stan::math
- multi_student_t_log() : stan::math
- multi_student_t_rng() : stan::math
- multinomial_log() : stan::math
- multinomial_rng() : stan::math
- multiply() : stan::math
- multiply_log() : stan::math
- multiply_lower_tri_self_transpose() : stan::math

[ Stan Home Page ] © 2011–2016, Stan Development Team.